import { IEditorServices } from '@jupyterlab/codeeditor';
import { JupyterFrontEnd } from '@jupyterlab/application';
import { Widget } from '@lumino/widgets';
import { Drag } from '@lumino/dragdrop';
import { ReadonlyPartialJSONObject } from '@lumino/coreutils';
import React from 'react';
import { CodeSnippetService, ICodeSnippet } from './CodeSnippetService';
/**
 * CodeSnippetDisplay props.
 */
interface ICodeSnippetDisplayProps {
    codeSnippets: ICodeSnippet[];
    codeSnippetManager: CodeSnippetService;
    app: JupyterFrontEnd;
    getCurrentWidget: () => Widget;
    openCodeSnippetEditor: (args: ReadonlyPartialJSONObject) => void;
    editorServices: IEditorServices;
    updateCodeSnippetWidget: () => void;
}
/**
 * CodeSnippetDisplay state.
 */
interface ICodeSnippetDisplayState {
    searchValue: string;
    filterTags: string[];
    selectedLangTags: string[];
    searchOptions: string[];
}
/**
 * A React Component for code-snippets display list.
 */
export declare class CodeSnippetDisplay extends React.Component<ICodeSnippetDisplayProps, ICodeSnippetDisplayState> {
    _drag: Drag;
    _dragData: {
        pressX: number;
        pressY: number;
        dragImage: HTMLElement;
    };
    constructor(props: ICodeSnippetDisplayProps);
    filterSnippets: (codeSnippets: ICodeSnippet[], searchValue: string, filterTags: string[], selectedLangTags: string[]) => {
        filteredCodeSnippets: ICodeSnippet[];
        matchedIndices: {
            [id: number]: number[];
        };
    };
    private insertCodeSnippet;
    private verifyLanguageAndInsert;
    private showWarnDialog;
    private showErrDialog;
    private dragHoverStyle;
    private dragHoverStyleRemove;
    private boldNameOnSearch;
    private handleRenameSnippet;
    private handleDragSnippet;
    private _evtMouseUp;
    private handleDragMove;
    /**
     * Detect if a drag event should be started. This is down if the
     * mouse is moved beyond a certain distance (DRAG_THRESHOLD).
     *
     * @param prevX - X Coordinate of the mouse pointer during the mousedown event
     * @param prevY - Y Coordinate of the mouse pointer during the mousedown event
     * @param nextX - Current X Coordinate of the mouse pointer
     * @param nextY - Current Y Coordinate of the mouse pointer
     */
    private shouldStartDrag;
    private startDrag;
    private _evtMouseLeave;
    private _setPreviewPosition;
    private _setOptionsPosition;
    private renderLanguageIcon;
    private renderCodeSnippet;
    renderDescription(codeSnippet: ICodeSnippet, id: number): JSX.Element;
    handleFilter: (searchValue: string, filterTags: string[], selectedLangTags: string[]) => void;
    getActiveTags(): string[][];
    getActiveTagsDictionary: () => Map<string, string[]>;
    private deleteCommand;
    private exportCommand;
    private removeOptionsNode;
    createOptionsNode(codeSnippet: ICodeSnippet): HTMLElement;
    setSearchOptions(selectedOptions: string[]): void;
    render(): React.ReactElement;
}
export {};
