// Copyright (c) 2020, jupytercalpoly
// Distributed under the terms of the BSD-3 Clause License.
import { checkIcon, addIcon } from '@jupyterlab/ui-components';
import React from 'react';
/**
 * CSS STYLING
 */
const CODE_SNIPPET_EDITOR_TAG = 'jp-codeSnippet-editor-tag';
const CODE_SNIPPET_EDITOR_TAG_PLUS_ICON = 'jp-codeSnippet-editor-tag-plusIcon';
const CODE_SNIPPET_EDITOR_TAG_LIST = 'jp-codeSnippet-editor-tagList';
export class CodeSnippetEditorTags extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            allSnippetTags: [],
            plusIconClicked: false,
        };
        this.renderTags = this.renderTags.bind(this);
        this.handleClick = this.handleClick.bind(this);
    }
    componentDidMount() {
        this.setState({
            allSnippetTags: this.props.allSnippetTags,
            plusIconClicked: false,
        });
    }
    componentDidUpdate(prevProps) {
        if (prevProps !== this.props) {
            this.setState({
                allSnippetTags: this.props.allSnippetTags,
            });
        }
    }
    handleClick(event) {
        const target = event.target;
        const clickedTag = target.innerText;
        this.handleClickHelper(clickedTag);
    }
    handleOnChange() {
        this.props.handleChange(this.state.allSnippetTags);
    }
    handleClickHelper(
    // parent: HTMLElement,
    clickedTag) {
        this.setState((state) => ({
            allSnippetTags: state.allSnippetTags.map((tag) => tag.name === clickedTag ? Object.assign(Object.assign({}, tag), { clicked: !tag.clicked }) : tag),
        }), this.handleOnChange);
    }
    addTagOnClick(event) {
        this.setState({ plusIconClicked: true });
        const inputElement = event.target;
        if (inputElement.value === 'Add Tag') {
            inputElement.value = '';
            inputElement.style.width = '62px';
            inputElement.style.minWidth = '62px';
        }
    }
    addTagOnKeyDown(event) {
        const inputElement = event.target;
        if (inputElement.value !== '' && event.key === 'Enter') {
            if (this.state.allSnippetTags.find((tag) => tag.name === inputElement.value)) {
                alert('Duplicate Tag Name!');
                return;
            }
            if (this.props.langTags.includes(inputElement.value)) {
                alert('This tag already exists in language tags!\nIf you want to create this tag, lowercase the first letter.');
                return;
            }
            const newTag = { name: inputElement.value, clicked: true };
            this.setState((state) => ({
                allSnippetTags: [...state.allSnippetTags, newTag],
                plusIconClicked: false,
            }), this.handleOnChange);
        }
    }
    addTagOnBlur(event) {
        const inputElement = event.target;
        inputElement.value = 'Add Tag';
        inputElement.style.width = '50px';
        inputElement.style.minWidth = '50px';
        inputElement.blur();
        this.setState({ plusIconClicked: false });
    }
    renderTags() {
        const hasTags = this.state.allSnippetTags;
        const inputBox = this.state.plusIconClicked === true ? (React.createElement("ul", { className: `${CODE_SNIPPET_EDITOR_TAG} tag unapplied-tag`, key: 'editor-new-tag' },
            React.createElement("input", { onClick: (event) => this.addTagOnClick(event), onKeyDown: (event) => this.addTagOnKeyDown(event), onBlur: (event) => this.addTagOnBlur(event), autoFocus: true }))) : (React.createElement("ul", { className: `${CODE_SNIPPET_EDITOR_TAG} tag unapplied-tag` },
            React.createElement("button", { onClick: () => this.setState({ plusIconClicked: true }) }, "Add Tag"),
            React.createElement(addIcon.react, { tag: "span", className: CODE_SNIPPET_EDITOR_TAG_PLUS_ICON, elementPosition: "center", height: "16px", width: "16px", marginLeft: "2px" })));
        return (React.createElement("li", { className: CODE_SNIPPET_EDITOR_TAG_LIST },
            hasTags
                ? this.state.allSnippetTags.map((tag, index) => (() => {
                    if (!tag.clicked) {
                        return (React.createElement("ul", { className: `${CODE_SNIPPET_EDITOR_TAG} tag unapplied-tag`, id: 'editor' + '-' + tag.name + '-' + index, key: 'editor' + '-' + tag.name + '-' + index },
                            React.createElement("button", { onClick: this.handleClick }, tag.name)));
                    }
                    else {
                        return (React.createElement("ul", { className: `${CODE_SNIPPET_EDITOR_TAG} tag applied-tag`, id: 'editor' + '-' + tag.name + '-' + index, key: 'editor' + '-' + tag.name + '-' + index },
                            React.createElement("button", { onClick: this.handleClick }, tag.name),
                            React.createElement(checkIcon.react, { tag: "span", elementPosition: "center", height: "18px", width: "18px", marginLeft: "5px", marginRight: "-3px" })));
                    }
                })())
                : null,
            inputBox));
    }
    render() {
        return React.createElement("div", null, this.renderTags());
    }
}
